Enum Error
pub enum Error {
InvalidToken,
IoError(Error),
OtherError(Box<dyn Error + Sync + Send>),
}wayland_platform only.Expand description
The primary error type used by Calloop covering internal errors and I/O errors that arise during loop operations such as source registration or event dispatching.
Variants
InvalidToken
When an event source is registered (or re- or un-registered) with the event loop, this error variant will occur if the token Calloop uses to keep track of the event source is not valid.
IoError(Error)
This variant wraps a std::io::Error, which might arise from
Calloop’s internal operations.
OtherError(Box<dyn Error + Sync + Send>)
Any other unexpected error kind (most likely from a user implementation of
EventSource::process_events()) will be wrapped in this.